struct LayoutImageContext {
id: PendingImageId,
cache: Arc<dyn ImageCache>,
doc: Trusted<Document>,
url: ServoUrl,
}Fields
id: PendingImageIdcache: Arc<dyn ImageCache>doc: Trusted<Document>url: ServoUrlTrait Implementations
Sourceimpl FetchResponseListener for LayoutImageContext
impl FetchResponseListener for LayoutImageContext
fn process_request_body(&mut self, _: RequestId)
fn process_response( &mut self, _: &mut JSContext, request_id: RequestId, metadata: Result<FetchMetadata, NetworkError>, )
fn process_response_chunk( &mut self, _: &mut JSContext, request_id: RequestId, payload: Vec<u8>, )
fn process_response_eof( self, cx: &mut JSContext, request_id: RequestId, response: Result<(), NetworkError>, timing: ResourceFetchTiming, )
fn process_csp_violations( &mut self, _request_id: RequestId, violations: Vec<Violation>, )
Sourcefn should_invoke(&self) -> bool
fn should_invoke(&self) -> bool
A gating mechanism that runs before invoking the listener methods on the target
thread. If the
should_invoke method returns false, the listener does not receive
the notification.Sourceimpl ResourceTimingListener for LayoutImageContext
impl ResourceTimingListener for LayoutImageContext
fn resource_timing_information(&self) -> (InitiatorType, ServoUrl)
fn resource_timing_global(&self) -> DomRoot<GlobalScope>